@@ -4,7 +4,7 @@ package PONAPI::Server;
 use strict;
 use warnings;
 
-our $VERSION = '0.002017';
+our $VERSION = '0.003000';
 
 use Plack::Request;
 use Plack::Response;
@@ -14,7 +14,7 @@ use JSON::XS           ();
 use URI::Escape        qw( uri_unescape );
 
 use PONAPI::Server::ConfigReader;
-use PONAPI::Utils::Names qw( check_name );
+use PONAPI::Names qw( check_name );
 
 use parent 'Plack::Component';
 
@@ -396,7 +396,7 @@ PONAPI::Server - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/
 
 =head1 VERSION
 
-version 0.002017
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -414,7 +414,7 @@ C<PONAPI::Server> is a small plack server that implements the
 L<{json:api}|http://jsonapi.org/> specification.
 
 You'll have to set up a repository (to provide access to the data
-you want to server) and tweak some server configurations, so
+you want to serve) and tweak some server configurations, so
 hop over to L<PONAPI::Manual> for the next steps!
 
 =head1 BUGS, CONTACT AND SUPPORT
